@@ -6,6 +6,7 @@ class ApiException(Exception):
     def __init__(self, message, response, detail=""):
         try:
             self.status_code = response.status_code
+            self.response = response.json()
             if response.json().get("Error"):
                 logging.error(f"{response.status_code}: {response.json()}")
                 self.message = f"Api Exception: {response.status_code} -{detail} {response.json()['Error']}"
@@ -15,6 +16,7 @@ class ApiException(Exception):
         except:
             if response.content:
                 logging.error(f"{response.status_code}: {response.content}")
+                self.response = response.content
             else:
                 logging.error(f"{response.status_code}: {message}")
             self.message = f"Api Exception:{detail} {message}"
